@@ -17,6 +17,7 @@
 
 ##  $Id: 00Init.r,v 1.9 2009/11/05 18:53:26 burgerm Exp $
 
+RUnitEnv <- new.env()
 
 .onLoad <- function(libname, pkgname)
 {
@@ -25,15 +26,8 @@
   ## Not to be called by users.
   ##@edescr
 
-  ##  load required packages
-  errMsg <- paste("\nLoading required package 'methods' failed. RUnit could not be loaded.",
-                  "\nCheck your library installation path.\n")
-  require(methods) || stop(errMsg)
-
-  
-  runitVersion <- packageDescription("RUnit", lib.loc=libname, fields="Version")
-  ##  avoid cmd check NOTEs
-  assign(".testLogger", NULL, envir=.GlobalEnv)
+##  runitVersion <- packageDescription("RUnit", lib.loc=libname, fields="Version")
+  assign(".testLogger", NULL, envir=RUnitEnv)
   ##  add options to R's global options list
   .buildRUnitOptions()
 }
